# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`nextcloud`](#nextcloud): Install and configure Nextcloud

_Private Classes_

* `nextcloud::config`: Configure Nextcloud instance
* `nextcloud::install`: Handle nextcloud installation

**Resource types**

_Public Resource types_


_Private Resource types_

* `nextcloud_application`: This type provides Puppet with the capabilities to manage Nextcloud apps

**Data types**

* [`Nextcloud::Config`](#nextcloudconfig): handle settings of config.php
* [`Nextcloud::Config::Redis`](#nextcloudconfigredis): handle redis part of settings in config.php

## Classes

### nextcloud

Install and configure Nextcloud

#### Examples

##### 

```puppet
class { 'nextcloud':
  version           => '18.0.2',
  database_host     => '10.0.0.10',
  database_name     => 'nextcloud_dnname',
  database_user     => 'nextcloud_dbuser',
  database_password => 'secret',
  additional_apps   => ['unsplash'],
}
```

#### Parameters

The following parameters are available in the `nextcloud` class.

##### `archive_url`

Data type: `Stdlib::HTTPUrl`

URL from which the Nextcloud archive will be downloaded

Default value: 'https://download.nextcloud.com/server/releases/'

##### `manage_phplibs`

Data type: `Boolean`

false: you have to manage somewhere else the required php libs.
true: the module installs php packages (which are listed in phplibs)

Default value: `true`

##### `phplibs`

Data type: `Array`

If manage_phplibs is true, list of php packages to be installed.

Default value: ['php7.2','php7.2-zip','php7.2-xml','php7.2-mbstring','php7.2-curl','php7.2-gd','php7.2-json','php-imagick','php7.2-intl','php-redis']

##### `manage_redis`

Data type: `Boolean`

false: the module does not install redis on the node.
true: a redis service is installed on the node and bound to 127.0.0.1

Default value: `true`

##### `system_user`

Data type: `String`

System account existong on node that own Nextcloud files.

Default value: 'www-data'

##### `version`

Data type: `String`

Version of installed Nexcloud.

Default value: '18.0.3'

##### `additional_apps`

Data type: `Array[String]`

Nextcloud can be extended by applications. You can give a list a additional applications here.

Default value: []

##### `database_driver`

Data type: `Enum['mysql']`

The database engine used as backend.

Default value: 'mysql'

##### `database_host`

Data type: `Stdlib::Host`

Host address of the database used as backend.

Default value: '127.0.0.1'

##### `database_name`

Data type: `String`

Name of the database used as backend.

Default value: 'nextcloud'

##### `database_user`

Data type: `String`

User accound used to connect the database.

Default value: 'nextcloud'

##### `database_password`

Data type: `String[1]`

Password used to connect the database

##### `config`

Data type: `Nextcloud::Config`

Content of config.php, details of handled settings described in custom data type Nextcloud::Config and Nextcloud::Config::Redis.

Default value: {}

## Resource types

## Data types

### Nextcloud::Config

handle settings of config.php

Alias of `Struct[{
  Optional['trusted_domains']        => Array[String],
  Optional['datadirectory']          => Stdlib::Absolutepath,
  Optional['redis']                  => Nextcloud::Config::Redis,
  Optional['filelocking.enabled']    => Boolean,
  Optional['memcache.locking']       => String,
  Optional['memcache.distributed']   => String,
  Optional['memcache.local']         => String,
  Optional['mail_smtpmode']          => Enum['smtp','sendmail','qmail'],
  Optional['mail_smtphost']          => String,
  Optional['mail_smtpport']          => Integer,
  Optional['mail_smtptimeout']       => Integer,
  Optional['mail_smtpsecure']        => Enum['ssl','tls'],
  Optional['mail_smtpauth']          => Boolean,
  Optional['mail_smtpauthtype']      => Enum['LOGIN','PLAIN'],
  Optional['mail_smtpname']          => String,
  Optional['mail_smtppassword']      => String,
}]`

### Nextcloud::Config::Redis

handle redis part of settings in config.php

Alias of `Struct[{
  Optional['host']    => Stdlib::Host,
  Optional['port']    => Stdlib::Port,
  Optional['timeout'] => String,
}]`

